<?php

namespace Drupal\posthog_commerce\EventSubscriber;

use Drupal\commerce_cart\CartProviderInterface;
use Drupal\commerce_cart\Event\CartEntityAddEvent;
use Drupal\commerce_cart\Event\CartEvents;
use Drupal\posthog_php\SdkInterface;
use Drupal\posthog_php\UserHelper;
use Drupal\state_machine\Event\WorkflowTransitionEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Checkout subscriber.
 */
class CheckoutSubscriber implements EventSubscriberInterface {

  /**
   * Constructs a new CheckoutSubscriber object.
   *
   * @param \Drupal\commerce_cart\CartProviderInterface $cart_provider
   *   The cart provider.
   */
  public function __construct(
    protected readonly CartProviderInterface $cartProvider,
    protected readonly SdkInterface $posthogPhpSdk,
    protected readonly UserHelper $posthogUserHelper,
  ) {
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      CartEvents::CART_ENTITY_ADD => 'addToCart',
      'commerce_order.place.post_transition' => 'purchase',
    ];
  }

  /**
   * Add to cart event.
   *
   * @param \Drupal\commerce_cart\Event\CartEntityAddEvent $event
   *   The cart entity add event.
   */
  public function addToCart(CartEntityAddEvent $event) {
    $orderItem = $event->getOrderItem();
    if (!empty($orderItem)) {

      $distinctUserId = $this->posthogUserHelper->getDistinctId();
      $data = [
        // @todo Serialize order item data!
      ];
      // @todo Make event name configurable or a constant:
      $this->posthogPhpSdk->captureUserEvent($distinctUserId, 'addToCart', $data);
    }
  }

  /**
   * Purchase event.
   *
   * @param \Drupal\state_machine\Event\WorkflowTransitionEvent $event
   *   The workflow transition event.
   */
  public function purchase(WorkflowTransitionEvent $event) {
    /** @var \Drupal\commerce_order\Entity\OrderInterface $order */
    $order = $event->getEntity();
    if (!empty($order)) {
      $distinctUserId = $this->posthogUserHelper->getDistinctId();
      $data = [
        // @todo Serialize order item data!
      ];
      // @todo Make event name configurable or a constant:
      $this->posthogPhpSdk->captureUserEvent($distinctUserId, 'purchase', $data);
    }
  }

}
