/**
 * @file
 * Defines Javascript behaviors for the cookies module.
 */
(function (Drupal) {
  /**
   * Define defaults.
   */
  Drupal.behaviors.posthog_cookies = {
    consentGiven() {
      // Allow setting cookies. This replaced "memory" by the default cookie
      // tracking:
      // Note, that only users on which the posthog_js conditions apply to
      //  can get tracked, so we need to check, if window.posthog even exists:
      if (window.posthog) {
        // @todo Only set if not already set.
        window.posthog.set_config({ persistence: 'localStorage+cookie' });
      }
    },

    attach(context) {
      const self = this;
      document.addEventListener('cookiesjsrUserConsent', function (event) {
        const service =
          typeof event.detail.services === 'object'
            ? event.detail.services
            : {};
        if (typeof service.analytics !== 'undefined' && service.analytics) {
          self.consentGiven(context);
        }
      });
    },
  };
})(Drupal);
