/**
 * @file
 * Posthog JS initialization.
 */
(function (Drupal, drupalSettings) {
  Drupal.behaviors.posthog_js_init = {
    // @todo: Ensure that Drupal.attach is not too late! Eventually we should
    // just call this without attach?
    attach(context, settings) {
      const posthogJsSettings = drupalSettings.posthog_js;
      if (context !== document) {
        // Only initialize on page load, not for AJAX content
        // We MIGHT need to improve that in the future.
        return;
      }
      if (window.posthog == null) {
        // window.posthog should have been initialized here already
        // by load.js from cdn or local library.
        // Show a clear error, if it's still not available.
        throw new Error(
          `posthog_js: posthog-js SDK could not be loaded! You've chosen loading from: ${
            posthogJsSettings.cdn ? 'CND' : 'posthog-js library'
          }`,
        );
      }
      if (!posthogJsSettings.api_key) {
        throw new Error(
          'posthog_js: Unable to initialize posthog! Missing API-Key!',
        );
      }
      if (!posthogJsSettings.host) {
        throw new Error(
          'posthog_js: Unable to initialize posthog! Missing API-Host!',
        );
      }
      Drupal.posthog = window.posthog.init(posthogJsSettings.api_key, {
        api_host: posthogJsSettings.host,
        ...posthogJsSettings.init_config_json,
      });
    },
  };
})(Drupal, drupalSettings);
