<?php

declare(strict_types=1);

namespace Drupal\posthog\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Posthog settings for this site.
 */
final class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'posthog_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['posthog.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form['host'] = [
      '#type' => 'url',
      '#title' => $this->t('Posthog host'),
      '#required' => TRUE,
      '#default_value' => $this->config('posthog.settings')->get('host'),
      '#default' => $this->t("The Posthog host to communicate with, e.g. https://eu.i.posthog.com or https://us.i.posthog.com or your custom Posthog host. See https://posthog.com/docs/api for details."),
    ];
    $form['api_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Posthog project API key'),
      '#required' => TRUE,
      '#default_value' => $this->config('posthog.settings')->get('api_key'),
      '#default' => $this->t('Your posthog project API key. You can find your project API key and instance address in the <a rel="noopener noreferrer" href="https://app.posthog.com/project/settings" target="_blank">project settings</a> page in PostHog.'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->config('posthog.settings')
      ->set('host', $form_state->getValue('host'))
      ->set('api_key', $form_state->getValue('api_key'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
